# {{project_name}} - Technical Specification

**Author:** {{user_name}}
**Date:** {{date}}
**Project Level:** {{project_level}}
**Change Type:** {{change_type}}
**Development Context:** {{development_context}}

---

## Context

### Available Documents

{{loaded_documents_summary}}

### Project Stack

{{project_stack_summary}}

### Existing Codebase Structure

{{existing_structure_summary}}

---

## The Change

### Problem Statement

{{problem_statement}}

### Proposed Solution

{{solution_overview}}

### Scope

**In Scope:**

{{scope_in}}

**Out of Scope:**

{{scope_out}}

---

## Implementation Details

### Source Tree Changes

{{source_tree_changes}}

### Technical Approach

{{technical_approach}}

### Existing Patterns to Follow

{{existing_patterns}}

### Integration Points

{{integration_points}}

---

## Development Context

### Relevant Existing Code

{{existing_code_references}}

### Dependencies

**Framework/Libraries:**

{{framework_dependencies}}

**Internal Modules:**

{{internal_dependencies}}

### Configuration Changes

{{configuration_changes}}

### Existing Conventions (Brownfield)

{{existing_conventions}}

### Test Framework & Standards

{{test_framework_info}}

---

## Implementation Stack

{{implementation_stack}}

---

## Technical Details

{{technical_details}}

---

## Development Setup

{{development_setup}}

---

## Implementation Guide

### Setup Steps

{{setup_steps}}

### Implementation Steps

{{implementation_steps}}

### Testing Strategy

{{testing_strategy}}

### Acceptance Criteria

{{acceptance_criteria}}

---

## Developer Resources

### File Paths Reference

{{file_paths_complete}}

### Key Code Locations

{{key_code_locations}}

### Testing Locations

{{testing_locations}}

### Documentation to Update

{{documentation_updates}}

---

## UX/UI Considerations

{{ux_ui_considerations}}

---

## Testing Approach

{{testing_approach}}

---

## Deployment Strategy

### Deployment Steps

{{deployment_steps}}

### Rollback Plan

{{rollback_plan}}

### Monitoring

{{monitoring_approach}}
